@@ -131,11 +131,11 @@ def EditUserName():
     text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
      "It will be used in the records file, this makes it easier\n" + \
      "when you want to share your sleep pattern with others.", 0,  data.user)
-    if(text != ""):
-        data.user=unicode(text[0])
-        config.set('main', 'user', str(data.user.encode( "utf-8" )))    
-    else:
-        pass
+#    if(text != ""):
+    data.user=unicode(text[0])
+    config.set('main', 'user', str(data.user.encode( "utf-8" )))    
+#    else:
+#        pass
     print "User name:",  data.user
 
 
@@ -431,7 +431,7 @@ class frmStartWindow(QMainWindow):
     # Show the log window (where the data from a file gets visualised)
     ###########################################################################
     def ShowViewWindow(self):
-        global ViewWindowGraph       
+        global ViewWindowGraph       ,  WidgetGraph
         
         #reset to default log folder
         if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
@@ -456,6 +456,15 @@ class frmStartWindow(QMainWindow):
                 print "Set folder=",  data.logfolder,  ", file=",  data.logfilename
         
         ViewWindowGraph = ViewWindowCanvas(self)
+#        ViewWindowGraph = ViewWindowCanvas(ViewWindow.ui.WidgetGraph)
+#        ViewWindowGraph = ViewWindowCanvas(ViewWindow.ui.scrollAreaWidgetContents)
+#        ViewWindowGraph.setGeometry(QtCore.QRect(0, 0, 1000, 500))
+#        ViewWindow.ui.horizontalLayout.addWidget(ViewWindowGraph)
+
+#        ViewWindow.ui.lblTest = QtGui.QLabel(ViewWindow.ui.WidgetGraph)
+#        ViewWindow.ui.lblTest.setGeometry(QtCore.QRect(0, 0, 100, 50))
+        
+        
         ViewWindow.ShowLogFile()
         
         if(data.logfilename!=""):
@@ -1103,7 +1112,7 @@ class frmConfigWindow(QMainWindow):
     ###########################################################################
     def EditUserName(self):
         EditUserName()
-        self.ui.lblUser.setText(data.user)
+        self.ui.lblUser.setText("User name: "+data.user)
         
 
     ###########################################################################
@@ -1112,7 +1121,7 @@ class frmConfigWindow(QMainWindow):
     def DelaySliderMoved(self):
         x=self.ui.SlrDelayStart.value()
         data.DelayStartTime=x
-        self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
+        self.ui.lblDelayStart.setText("Start delay: "+str(data.DelayStartTime)+" sec")
 
 
     ###########################################################################
@@ -1474,7 +1483,7 @@ class RecordWindowCanvas(QtGui.QWidget):
         QMainWindow.__init__(self, parent)    
         self.setGeometry(9, 180, 782, data.Ysize+55)
 
-    ###########################################################################
+#    ###########################################################################
     ## 
     ###########################################################################
     def paintEvent(self, event):
